OrangeCompactTypography class
Orange-specific typography that applies Helvetica font weight adjustments.
This class extends OudsTypography and applies the .withOrangeFont()
extension to all text styles to ensure proper Helvetica Neue font variants
are used based on the font weight.
- Inheritance
-
- Object
- OudsTypography
- OrangeCompactTypography
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
typeBodyDefaultLarge(
BuildContext context) → TextStyle -
Body Default
override
-
typeBodyDefaultMedium(
BuildContext context) → TextStyle -
override
-
typeBodyDefaultSmall(
BuildContext context) → TextStyle -
override
-
typeBodyModerateLarge(
BuildContext context) → TextStyle -
Body Moderate
override
-
typeBodyModerateMedium(
BuildContext context) → TextStyle -
override
-
typeBodyModerateSmall(
BuildContext context) → TextStyle -
override
-
typeBodyStrongLarge(
BuildContext context) → TextStyle -
Body Strong
override
-
typeBodyStrongMedium(
BuildContext context) → TextStyle -
override
-
typeBodyStrongSmall(
BuildContext context) → TextStyle -
override
-
typeDisplayLarge(
BuildContext context) → TextStyle -
override
-
typeDisplayMedium(
BuildContext context) → TextStyle -
Display
override
-
typeDisplaySmall(
BuildContext context) → TextStyle -
override
-
typeHeadingLarge(
BuildContext context) → TextStyle -
override
-
typeHeadingMedium(
BuildContext context) → TextStyle -
override
-
typeHeadingSmall(
BuildContext context) → TextStyle -
override
-
typeHeadingXLarge(
BuildContext context) → TextStyle -
Heading
override
-
typeLabelDefaultLarge(
BuildContext context) → TextStyle -
override
-
typeLabelDefaultMedium(
BuildContext context) → TextStyle -
override
-
typeLabelDefaultSmall(
BuildContext context) → TextStyle -
override
-
typeLabelDefaultXLarge(
BuildContext context) → TextStyle -
Label Default
override
-
typeLabelModerateLarge(
BuildContext context) → TextStyle -
override
-
typeLabelModerateMedium(
BuildContext context) → TextStyle -
override
-
typeLabelModerateSmall(
BuildContext context) → TextStyle -
override
-
typeLabelModerateXLarge(
BuildContext context) → TextStyle -
Label Moderate
override
-
typeLabelStrongLarge(
BuildContext context) → TextStyle -
override
-
typeLabelStrongMedium(
BuildContext context) → TextStyle -
override
-
typeLabelStrongSmall(
BuildContext context) → TextStyle -
override
-
typeLabelStrongXLarge(
BuildContext context) → TextStyle -
Label Strong
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited